/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/** \file 
 * \brief Plik procedury o bledach uzytkownika/programu.
 *
 * Kazda funkcja zaczyna sie przedrostkiem error
 * Tak naprawde to to sa procedury ale moze warto to zmienic
 * \author Michal Lachowicz <MLachowicz@elka.pw.edu.pl>
 */

#include "error.h"

/// Pokazuje okienko z bledem

/** Przydatne w czasie walidacji.
 * \param window Bierzace okno
 * \param pole Pole, ktore zglosilo blad
 * \param wartosc Nieprawidlowa wartosc.
 */
void
errorPoleWartosc (GtkWindow * window, gchar * pole, gchar * wartosc)
{

  GtkWidget *dialog;

  g_print ("Bledna wartosc `%s' w polu %s\n", wartosc, pole);

  dialog = gtk_message_dialog_new (window,
				   GTK_DIALOG_MODAL,
				   GTK_MESSAGE_INFO,
				   GTK_BUTTONS_OK,
				   "Błędna wartość `%s` w polu %s",
				   wartosc, pole);
  gtk_dialog_run (GTK_DIALOG (dialog));
  gtk_widget_destroy (dialog);

}

void
errorNazwaKontrahenta (GtkWindow * window, gchar * tmp)
{

  errorPoleWartosc (window, "Nazwa Kontrahenta", tmp);

}

void
errorRegon (GtkWindow * window, gchar * tmp)
{

  errorPoleWartosc (window, "Regon", tmp);

}

void
errorUlica (GtkWindow * window, gchar * tmp)
{

  errorPoleWartosc (window, "Ulica", tmp);

}

void
errorMiejscowosc (GtkWindow * window, gchar * tmp)
{

  errorPoleWartosc (window, "Miejscowosc", tmp);

}

void
errorPodpis (GtkWindow * window, gchar * tmp)
{

  errorPoleWartosc (window, "Podpis", tmp);

}

/** Pokazuje okno w przypadku braku polaczenia z baza danych
 * 
 * Pyta czy Kontynuowac
 * \retval gboolean Kontynuować
 */

gboolean
errorPolaczenie ()
{
  GtkWidget *dialog;
  gint result;

  g_print ("Nie mozna nawiazac polaczenia z baza danych\n");

  dialog = gtk_message_dialog_new (GTK_WINDOW (fakturaWindow),
				   GTK_DIALOG_MODAL,
				   GTK_MESSAGE_INFO,
				   GTK_BUTTONS_YES_NO,
				   "Nie można nawiazać połączenia z bazą danych. Czy chcesz kontynuować ?");
  //jezeli user kliknal Tak to TRUE

  result = gtk_dialog_run (GTK_DIALOG (dialog));

  gtk_widget_destroy (dialog);

  return (result == GTK_RESPONSE_YES ? TRUE : FALSE);

}

/** Pokazywane okno w przypadku bledu bazy danych
 * 
 * Wyswietla komunikat zwracany przez mysql_error
 * \retval gboolean Kontynuować
 */

gboolean
errorMySql (GtkWindow * window)
{
  GtkWidget *dialog;

  g_print ("Blad bazy danych `%s' \n", mysql_error (&mysql));

  dialog = gtk_message_dialog_new (window,
				   GTK_DIALOG_MODAL,
				   GTK_MESSAGE_INFO,
				   GTK_BUTTONS_OK,
				   "Bład bazy danych `%s'",
				   mysql_error (&mysql));
  gtk_dialog_run (GTK_DIALOG (dialog));
  gtk_widget_destroy (dialog);

}
