/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/** \file 
 * \brief Plik zawiera funkcje operujace na bazie danych.
 * 
 * Funkcje zwracajace wartosc TRUE jezeli wszystko sie powiodlo
 * Funkcje operuja rowniez na obiektach formularzy
 * \author Michal Lachowicz <MLachowicz@elka.pw.edu.pl>
 */


#include "sql.h"


///Podlacza baze danych do zmiennej globalnej mysql.



/** W przypadku bledu wyrzuca komunikaty na g_print  
 * \todo zmienic wpisane na stale ustawienia na
 * pobierane z jakiegos pliku konfiguracyjnego
 *
 * \retval gboolean Sukces
 */
gboolean
sqlInit ()
{

  mysql_init (&mysql);
//mysql_options(&mysql,MYSQL_READ_DEFAULT_GROUP,"your_prog_name");
  if (!mysql_real_connect
      (&mysql, "localhost", "root", "", "fakturix", 0, NULL, 0))
    {
      g_print ("Failed to connect to database: Error: %s\n",
	       mysql_error (&mysql));
      return FALSE;
    }
  return TRUE;
}

///Zamyka polaczenie z baza danych

/** \todo obsluga bledow zamykania polaczenia, zabezpieczenie przed NULL'em
 */

gboolean
sqlClose ()
{
  mysql_close (&mysql);
  return 0;
}

///Wypelnia GtkCList resultem zwracanym przez sql'a

/**     \fn gboolean sqlFillCList(  GtkCList *list, gchar *sql)
 *	\warning string musi zwracac dokladnie tyle pol ile kolumn ma lista
 *		\param list lista, ktora ma byc wypelniona;
 *		\param sql string, ktory zwroci rekordy;
 */

gboolean
sqlFillCList (GtkCList * list, gchar * sql)
{
  MYSQL_RES *result;
  MYSQL_ROW row;
  unsigned int num_fields;
  unsigned int num_rows;
  //unsigned int i;

  gtk_clist_clear (list);

  g_print ("string=%s\n", sql);

  if (mysql_query (&mysql, sql))
    {
      g_print ("mysql_query_error\n");
      // error
      g_print ("%s\n", mysql_error (&mysql));
      return FALSE;
    }
  else				// query succeeded, process any data returned by it
    {
      g_print ("mysql_query_success\n");
      result = mysql_store_result (&mysql);
      if (result)		// there are rows
	{
	  g_print ("mysql_store_result_suc\n");
	  num_fields = mysql_num_fields (result);
	  // retrieve rows, then call mysql_free_result(result)
	  while ((row = mysql_fetch_row (result)))
	    {
	      unsigned long *lengths;
	      lengths = mysql_fetch_lengths (result);

	      gtk_clist_insert (list, 1, row);

	      /*          for(i = 0; i < num_fields; i++)
	         {
	         printf("[%.*s] ", (int) lengths[i], row[i] ? row[i] : "NULL");
	         }
	         printf("\n");
	       */ }

	  mysql_free_result (result);
	}
      else			// mysql_store_result() returned nothing; should it have?
	{
	  g_print ("mysql_store_err\n");
	  if (mysql_errno (&mysql))
	    {
	      //fprintf(stderr, "Error: %s\n", mysql_error(&mysql));
	      return FALSE;
	    }
	  else if (mysql_field_count (&mysql) == 0)
	    {
	      // query does not return data
	      // (it was not a SELECT)
	      num_rows = mysql_affected_rows (&mysql);
	    }
	}
    }
  return TRUE;
}


///     Wypelnia Szczegoly w oknie fakturaWindow

/** 	Wywolywana po podaniu kodu towaru
 *      \fn gboolean sqlFillSzczegol(GtkWidget *kod)
 *	\param kod fakturaWindowEntrySzczegolyKod
 */

gboolean
sqlFillSzczegol (GtkWidget * kod)
{

  MYSQL_RES *result;
  MYSQL_ROW row;
  GString *str;
  unsigned int num_fields;
  unsigned int num_rows;
  unsigned int i;
  GtkWidget *fakturaWindow, *editable;

  str = g_string_new ("SELECT * FROM towar WHERE kod = ");

  str = g_string_append (str, gtk_entry_get_text (GTK_ENTRY (kod)));

  str = g_string_append (str, ";");

  g_print ("%s\n", str->str);


  if (mysql_query (&mysql, str->str))
    {
      g_print ("mysql_query_error\n");
      g_string_free (str, TRUE);
      // error
      return FALSE;
    }
  else				// query succeeded, process any data returned by it
    {
      g_print ("mysql_query_success\n");
      result = mysql_store_result (&mysql);
      if (result)		// there are rows
	{
	  g_print ("mysql_store_result_suc\n");
	  num_fields = mysql_num_fields (result);
	  // retrieve rows, then call mysql_free_result(result)
	  while ((row = mysql_fetch_row (result)))
	    {
	      unsigned long *lengths;
	      lengths = mysql_fetch_lengths (result);

	      fakturaWindow = gtk_widget_get_toplevel (kod);
	      editable = lookup_widget (fakturaWindow, "fakturaEntryNazwa");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[3]);

	      editable = lookup_widget (fakturaWindow, "fakturaEntryPkwiu");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[4]);

	      editable = lookup_widget (fakturaWindow, "fakturaEntryStawka");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[5]);

	      editable = lookup_widget (fakturaWindow, "fakturaEntryCena");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[5]);

	      for (i = 0; i < num_fields; i++)
		{
		  printf ("[%.*s] ", (int) lengths[i],
			  row[i] ? row[i] : "NULL");
		}
	      printf ("\n");

	    }

	  mysql_free_result (result);
	}
      else			// mysql_store_result() returned nothing; should it have?
	{
	  g_print ("mysql_store_err\n");
	  if (mysql_errno (&mysql))
	    {
	      g_string_free (str, TRUE);
	      return FALSE;
	    }
	  else if (mysql_field_count (&mysql) == 0)
	    {
	      // query does not return data
	      // (it was not a SELECT)
	      num_rows = mysql_affected_rows (&mysql);
	    }
	}
    }

  g_string_free (str, TRUE);
  return TRUE;

}

///     Wypelnia dane o kontrahencie w oknie fakturaWindow

/**	Wywolywana po podaniu NIP'u.
 *	\fn gboolean sqlFillKontrahent(GtkWidget *nip)
 *	\param nip fakturaWindowKontrahentNip
 *	\todo rozbic na pobieranie danych z bazy do zmiennej nabywca 
 *	typu struct fKontrahent 
 */
gboolean
sqlFillKontrahent (GtkWidget * nip)
{

  MYSQL_RES *result;
  MYSQL_ROW row;
  GString *str;
  gchar *temp;
  unsigned int num_fields;
  unsigned int num_rows;
  unsigned int i;
  //GtkWidget *fakturaWindow, 
  GtkWidget *editable;

  //fakturaWindow = gtk_widget_get_toplevel (nip);

  str = g_string_new ("SELECT * FROM kontrahent WHERE nip = '");

  // z finterface.c
  temp = fakturaWindowKontrahentNip ();

  str = g_string_append (str, temp);	//Dodanie Nip'u

  g_free (temp);

  str = g_string_append (str, "';");

  g_print ("%s\n", str->str);

  if (mysql_query (&mysql, str->str))
    {
      g_print ("mysql_query_error\n");
      g_string_free (str, TRUE);
      // error
      return FALSE;
    }
  else				// query succeeded, process any data returned by it
    {
      g_print ("mysql_query_success\n");
      result = mysql_store_result (&mysql);
      if (result)		// there are rows
	{
	  g_print ("mysql_store_result_suc\n");
	  num_fields = mysql_num_fields (result);
	  // retrieve rows, then call mysql_free_result(result)
	  while ((row = mysql_fetch_row (result)))
	    {
	      unsigned long *lengths;
	      lengths = mysql_fetch_lengths (result);

	      editable =
		lookup_widget (fakturaWindow, "fakturaEntryKontrahentNazwa");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[2]);

	      editable =
		lookup_widget (fakturaWindow, "fakturaEntryKontrahentUlica");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[4]);

	      g_print ("kod=%s\n", row[5]);

	      Egtk_entry_set_text (fakturaWindow,
				   "fakturaEntryKontrahentKod1", row[5]);
	      Egtk_entry_set_text (fakturaWindow,
				   "fakturaEntryKontrahentKod2", row[5] + 2);

	      editable =
		lookup_widget (fakturaWindow,
			       "fakturaEntryKontrahentMiejscowosc");
	      gtk_entry_set_text (GTK_ENTRY (editable), row[6]);

	      //editable = lookup_widget ( fakturaWindow, "fakturaEntryKontrahentUlica" );
	      //gtk_entry_set_text( GTK_ENTRY(editable) , row[5]);

	      for (i = 0; i < num_fields; i++)
		{
		  printf ("[%.*s] ", (int) lengths[i],
			  row[i] ? row[i] : "NULL");
		}
	      printf ("\n");

	    }

	  mysql_free_result (result);
	}
      else			// mysql_store_result() returned nothing; should it have?
	{
	  g_print ("mysql_store_err\n");
	  if (mysql_errno (&mysql))
	    {
	      g_string_free (str, TRUE);
	      return FALSE;
	    }
	  else if (mysql_field_count (&mysql) == 0)
	    {
	      // query does not return data
	      // (it was not a SELECT)
	      num_rows = mysql_affected_rows (&mysql);
	    }
	}
    }

  g_string_free (str, TRUE);
  return TRUE;

}

/**	\brief Dodaje towar do bazy
 * 
 * 	Dodaje towar na podstawie danych
 *	z okna towarWindow
 *	korzysta z struct fTowar
 *	\todo przerobic baze aby miala FLOATy
 */

gboolean
sqlAddTowar (struct fTowar * towar)
{

  GString *str;
  G_CONST_RETURN gchar *sql, *tmp;

  GtkEntry *entry;

  sql = "INSERT INTO towar\
                VALUES (0, '";

  str = g_string_new (sql);

  tmp = towar->kod;
  str = g_string_append (str, tmp);

  //Brak towar/usluga
  ///TODO:Pobierać daną z Radio a nie wpisywać wprost do kodu

  str = g_string_append (str, "', 'towar' ,'");
  //Nazwa
  tmp = towar->nazwa;
  str = g_string_append (str, tmp);

  str = g_string_append (str, "', '");
  //PKWiU
  tmp = towar->pkwiu;
  str = g_string_append (str, tmp);

  str = g_string_append (str, "', ");
  //Cena
  g_sprintf (tmp, "%f", towar->cena_jd);
  str = g_string_append (str, tmp);

  ///TODO:Stawka VAT
  str = g_string_append (str, ");");

  g_print ("%s\n", str->str);
  mysql_query (&mysql, str->str);

  g_string_free (str, TRUE);

  if (mysql_error (&mysql)[0] != '\0')
    {
      g_print ("%s\n", mysql_error (&mysql));
      return FALSE;
    }

  return TRUE;

}

/**	\brief Dodaje kontrahenta do bazy
 *	
 *	Dodaje kontrahenta na podstawie danych
 *	z okna kontrahentWindow
 *	Korzysta z struct fKontrahent
 */
gboolean
sqlAddKontrahent (struct fKontrahent * kontrahent)
{
  GString *str;
  G_CONST_RETURN gchar *sql, *tmp;

  sql = "INSERT INTO kontrahent\
		VALUES (0, ";

  str = g_string_new (sql);

  tmp = kontrahent->nip;
  str = g_string_append (str, tmp);

  str = g_string_append (str, ", '");

  tmp = kontrahent->nazwa;
  str = g_string_append (str, tmp);

  str = g_string_append (str, "',");

  tmp = kontrahent->regon;
  str = g_string_append (str, tmp);

  str = g_string_append (str, ",'");

  tmp = kontrahent->adres->ulica;
  str = g_string_append (str, tmp);

  str = g_string_append (str, "',");

  tmp = kontrahent->adres->kod;
  str = g_string_append (str, tmp);

  str = g_string_append (str, ",'");

  tmp = kontrahent->adres->miejscowosc;
  str = g_string_append (str, tmp);

  str = g_string_append (str, "','");

  tmp = kontrahent->podpis;	//gtk_entry_get_text (entry);
  str = g_string_append (str, tmp);

  str = g_string_append (str, "');");

  g_print ("%s\n", str->str);

  mysql_query (&mysql, str->str);

  g_string_free (str, TRUE);

  if (mysql_error (&mysql)[0] != '\0')
    {
      g_print ("%s\n", mysql_error (&mysql));
      return FALSE;
    }

  return TRUE;

}


/**	\brief Usuwa kontrahenta z bazy
 *
 * 	Usuwa kontrahenta z bazy danych na 
 *	podstawie zaznaczonego wiersza w clist
 *	\todo Przerobic tak aby parametrem byl kodTowaru
 * 	Reszta powinna byc obrabiana w callback.c
 *	\sa sqlDelTowar
 */
gboolean
sqlDelKontrahent (GtkCList * clist, gint row)
{
  GString *str;
  G_CONST_RETURN gchar *sql;
  gchar *tmp;
  gint col;

  col = 0;

  sql = "DELETE FROM kontrahent WHERE nip = '";

  str = g_string_new (sql);

  gtk_clist_get_text (clist, row, col, &tmp);

  str = g_string_append (str, tmp);

  str = g_string_append (str, "';");

  g_print ("str=%s\n", str->str);

  mysql_query (&mysql, str->str);

  g_string_free (str, TRUE);

  if (mysql_error (&mysql)[0] != '\0')
    {
      g_print ("%s\n", mysql_error (&mysql));
      return FALSE;
    }

  return TRUE;

}

/**	\brief Usuwa towar z bazy
 *
 *	Na podstawie id przekazywanego przez callback.c
 *	\param kod towaru do usuniecia
 */

gboolean
sqlDelTowar (gchar * kod)
{
  GString *str;
  G_CONST_RETURN gchar *sql;

  sql = "DELETE FROM towar WHERE kod = '";

  str = g_string_new (sql);

  str = g_string_append (str, kod);

  str = g_string_append (str, "';");

  g_print ("str=%s\n", str->str);

  mysql_query (&mysql, str->str);

  g_string_free (str, TRUE);

  if (mysql_error (&mysql)[0] != '\0')
    {
      g_print ("%s\n", mysql_error (&mysql));
      return FALSE;
    }

  return TRUE;
}
