/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/** \file 
 * \brief Typowe typy i struktury np Faktura, Kontrahent, etc.
 * 
 * Wszystkie struktury maja przedrostek f jak fakturix ;)
 * Struktury sa dobrym sposobem na przekazywanie parametrow
 * pomiedzy roznymi czesciami programu np.
 * print, walidacja, baza danych, interfejs.
 * \author MLachowicz <MLachowicz@elka.pw.edu.pl>
 */

#ifndef HAVE_TYPES_H_798432789342879

#define HAVE_TYPES_H_798432789342879

#include <glib.h>

/** \struct fFaktura types.h 
 * \brief Faktura taka jaka jest zapisywana w bazie
 * 
 * Uzywa GPtrArray'a 
 *
 */

struct fFaktura
{
  gint id1;
  gint id2;
  gchar *numer;
  gchar *miejscowosc_wystawienia;
  gchar *data_wystawienia;
  gchar *sposob_zaplaty;
  gchar *data_sprzedazy;
  gchar *otrzymujacy;
  gchar *wystawiajacy;
  struct fKontrahent *sprzedawca;
  struct fKontrahent *nabywca;
  gint szczegoly_ilosc;		// okresla wielkosc tablicy szczegoly
  GPtrArray *szczegoly;		// z struct fSzczegol
  struct fRazem *razem;
};


/** \struct fKontrahent types.h
 * \brief Sprzedawca i Nabywca
 */

typedef struct fKontrahent
{
  gint id1;
  gint id2;
  gchar *nazwa;
  gchar *nip;
  gchar *regon;
  gchar *telefon;
  gchar *email;
  gchar *konto;
  gchar *podpis;
  struct fAdres *adres;
} TKontrahent, PKontrahent;

/** \struct fAdres types.h
 * \brief Dane adresowe
 */

struct fAdres
{
  gchar *ulica;
  gchar *miejscowosc;
  gchar *kod;
};
/** \struct fSzczegol types.h
 * \brief Szczegoly Faktury
 */

struct fSzczegol
{
  gint lp;
  gchar *nazwa;
  gchar *pkwiu;
  gfloat ilosc;
  gchar *jd_miary;
  gfloat cena_jd;
  gfloat wartosc_netto;
  gchar *stawka_vat;
  gfloat kwota_podatku;
  gfloat wartosc_brutto;
};

/** \struct fRazem types.h
 * \brief Zestawienie koncowe faktury
 * 
 * Uzywa GPtrArray'a
 */
struct fRazem
{
  gfloat wartosc_netto;
  gfloat kwota_podatku_vat;
  gfloat wartosc_brutto;
  gint stawka_ilosc;		// okresla wielkosc tablicy stawka
  GPtrArray *stawka;		// z struct fStawka
};
/** \struct fStawka types.h
 * \brief Zestawienie wg. Stawek VAT
 */

struct fStawka
{
  gchar *stawka;
  gfloat wartosc_netto;
  gfloat kwota_podatku_vat;
  gfloat wartosc_brutto;
};

/** \struct fTowar types.h
 * \brief Towar
 */

struct fTowar
{
  gchar *kod;
  gchar *nazwa;
  gchar *pkwiu;
  gfloat ilosc;
  gfloat cena_jd;
  gchar *stawka_vat;
};

#endif // ifndef HAVE_TYPES_H_798432789342879
