/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/** \file 
 * \brief Plik zawiera funkcje sprawdzajace/walidujace dane.
 * 
 *  Sprawdzanie danych powinno odbywac sie przed
 *  dostepem do bazy danych.
 *  Wszystkie funkcje zwracaja TRUE w przypadku 
 *  poprawnych danych.
 *  Funkcje zaczynaja sie przedrostkiem `valid`
 */

#include "validate.h"

/// Sprawdza poprawnosc NIP'u

gboolean
validNip (gchar * strNip)
{
  if (strlen (strNip) != 10)
    return FALSE;

  return validLiczba (strNip);

}

///Sprawdza czy w string moze byc traktowany jako liczba calkowita

/** Sprawdza czy w danym stringu 
 * wystepuje inny znak niz cyfra
 * wtedy FALSE
 */
gboolean
validLiczba (gchar * s)
{
  gint i;

  for (i = 0; i < strlen (s); i++)
    if (!g_ascii_isdigit (s[i]))
      return FALSE;

  return TRUE;

}


/// Sprawdza poprawnosc Kodu Pocztowego

gboolean
validKod (gchar * strKod)
{

  if (EMPTY (strKod))
    return FALSE;
  if ((strlen (strKod)) != 5)
    return FALSE;

  return (validLiczba (strKod));

}

/// Sprawdza poprawnosc Nazwy Kontrahenta

gboolean
validNazwaKontrahenta (gchar * strNazwa)
{

  if ((!EMPTY (strNazwa)) && (strlen (strNazwa) <= 255))
    return TRUE;

  return FALSE;
}

/// Sprawdza poprawnosc REGONU

gboolean
validRegon (gchar * strRegon)
{

  if (strlen (strRegon) == 9)
    return TRUE;

  return FALSE;
}

/** Funkcja sprawdza poprawnosc ulicy
 */
gboolean
validUlica (gchar * strUlica)
{

  if ((!EMPTY (strUlica)) && (strlen (strUlica) <= 100))
    return TRUE;

  return FALSE;
}

/** Funkcja sprawdza poprawnosc Miejscowosci
 */
gboolean
validMiejscowosc (gchar * strMiejscowosc)
{

  if ((!EMPTY (strMiejscowosc)) && (strlen (strMiejscowosc) <= 100))
    return TRUE;

  return FALSE;

}

/** Funkcja sprawdza poprawnosc 
    Osoby uprawnionej do Podpisu
 */
gboolean
validPodpis (gchar * strPodpis)
{

  if ((!EMPTY (strPodpis)) && (strlen (strPodpis) <= 100))
    return TRUE;

  return FALSE;
}

/// \brief Sprawdza poprawnosc kodu towaru

gboolean
validKodTowaru (gchar * strKod)
{

  if ((!EMPTY (strKod)) && (strlen (strKod) == 6))
    return validLiczba (strKod);
}

/// \brief Sprawdza poprawnosc kontrahenta
///        W przypadku kiedy zly wyrzuca komunikat
///        i zwraca false
gboolean
validKontrahent (struct fKontrahent * kontrahent)
{
//Sprawdzanie poprawnosci Nazwy Kontrahenta
  if (!validNazwaKontrahenta (kontrahent->nazwa))
    {
      errorNazwaKontrahenta (GTK_WINDOW (kontrahentWindow),
			     kontrahent->nazwa);
      return FALSE;
    }

  //Sprawdzanie poprawnosci Regonu
  if (!validRegon (kontrahent->regon))
    {
      errorRegon (GTK_WINDOW (kontrahentWindow), kontrahent->regon);
      return FALSE;
    }

  //Sprawdzanie poprawnosci Ulicy
  if (!validUlica (kontrahent->adres->ulica))
    {
      errorUlica (GTK_WINDOW (kontrahentWindow), kontrahent->adres->ulica);
      return FALSE;
    }

  //Sprawdzanie poprawnosci Miejscowosci
  if (!validMiejscowosc (kontrahent->adres->miejscowosc))
    {
      errorMiejscowosc (GTK_WINDOW (kontrahentWindow),
			kontrahent->adres->miejscowosc);
      return FALSE;
    }

  //Sprawdzanie poprawnosci Podpis
  if (!validPodpis (kontrahent->podpis))
    {
      errorPodpis (GTK_WINDOW (kontrahentWindow), kontrahent->podpis);
      return FALSE;
    }

  return TRUE;


}
