/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/** \file
 * \brief Zawiera funkcje sprawdzajace/walidujace dane.
 *
 *  Sprawdzanie danych powinno odbywac sie przed
 *  dostepem do bazy danych.
 *  Wszystkie funkcje zwracaja TRUE w przypadku
 *  poprawnych danych.
 *  Funkcje zaczynaja sie przedrostkiem `valid`
 */

#ifndef HAVE_VALIDATE_H_798432789342879
#define HAVE_VALIDATE_H_798432789342879

#include <glib.h>
#include <config.h>
#include <gnome.h>
#include <stdlib.h>
#include <stdio.h>
#include "error.h"
#include "types.h"

#ifdef __cplusplus
extern "C"
{
#endif

  extern GtkWidget *kontrahentWindow;

/// Sprawdza czy string jest pusty
#define EMPTY(str)	( (strlen(str) == 0 ) ? TRUE : FALSE )

/** Funkcja sprawdza poprawnosc NIP'u
 */
  gboolean validNip (gchar * strNip);

/** Funkcja sprawdza poprawnosc Kodu Pocztowego
 */
  gboolean validKod (gchar * strKod);

/** Funkcja sprawdza poprawnosc Nazwy Kontrahenta
 */
  gboolean validNazwaKontrahenta (gchar * strNazwa);

/** Funkcja sprawdza poprawnosc REGONU
 */
  gboolean validRegon (gchar * strRegon);

/** Funkcja sprawdza poprawnosc ulicy
 */
  gboolean validUlica (gchar * strUlica);

/** Funkcja sprawdza poprawnosc Miejscowosci
 */
  gboolean validMiejscowosc (gchar * strMiejscowosc);

/** Funkcja sprawdza poprawnosc
    Osoby uprawnionej do Podpisu
 */
  gboolean validPodpis (gchar * strPodpis);

  gboolean validLiczba (gchar * s);

/// \brief Sprawdza poprawnosc kontrahenta
///        W przypadku kiedy zly wyrzuca komunikat
///        i zwraca false
    gboolean validKontrahent (struct fKontrahent *kontrahent);

#ifdef __cplusplus
}
#endif

#endif				//ifndef HAVE_VALIDATE_H_798432789342879
